#-----------------------------------------------------------------------------
#              		TEMPERATURE AND HUMIDITY ON THE CLOUD
#	       		=====================================
#
# In this project the DHT11 temperature and humidity sensor is connected to
# GPIO0 pin (D3) of the NodeMCU development board. The project reads the
# temperature and humidity and sends to the cloud where it can be accessed
# from anywhere. In addition, change of the temperature and the humidity
# can be plotted in the cloud.
#
# The DHT11 sensor chip is used to get the ambient temperature and the
# humidity. this chip is conencted to pin GPIO0 of the NodeMCU.
#
# The program uses the Thingspeak cloud service. The NodeMCU must be
# conencted to the Wi-Fi router before we can send data to the cloud.
#
#
#
# Program : 	cloud.py
# Date    : 	May, 2017
# Programmer: 	Dogan Ibrahim
#------------------------------------------------------------------------------
import network
import socket
import time
import dht
from machine import Pin

APIKEY = "QAAHT5XIK3ZB8736"
WriteChId = 265433

#
# This function connects to the Wi-Fi
#
def Connect_WiFi():
    net = network.WLAN(network.STA_IF)
    if not net.isconnected():
       net.active(True)
       net.connect(BTHub5-6SPN, af4b5e6243)
       print(net.ifconfig())


#
# This function returns the temperature and humidity
#
def TempHun():
    d = dht.DHT11(Pin(0))
    d.measure()
    t = d.temperature()
    h = d.humidity()
    return t, h

#
# Send data to Thingspeak. This function sends the temperature and
# humidity data to the cloud every 60 seconds
#
while True:
    Connect_WiFi()
    sock = socket.socket()
    addr = socket.getaddrinfo("api.thingspeak.com",80)[0][-1]
    sock.connect(addr)
    (t, h) = TempHun()
    host = "api.thingspeak.com"
    path = "api_key="+APIKEY+"&field1="+str(t)+"&field2="+str(h)
    sock.send(bytes("GET /update?%s HTTP/1.0\r\nHost: %s\r\n\r\n" %(path,host),"utf8"))
    sock.close()
    time.sleep(30)


   
















   

   