#-----------------------------------------------------------------------------
#              		USING THE SPI BUS FUNCTIONS
#	       		===========================
#
# In this project a DHT11 temperature and humidity sensor is connected to
# GPIO0 pin (D3) of the NodeMCU development board. In addition, a BarGraph
# Click board is connected to the NodeMCU. The BarGraph Click board is
# SPI bus compatible.
#
# The program reads the ambient temperature and displays it on the bargraph.
# The bargraph consists fo 10 LEDs and each ON LED adds 3 degrees Centigrade
# to the total temperature. Thus, for example if LEDs 1 and 2 are ON then
# the temperature is 6 degrees Centigrade. The resolution of the display
# is only 3 degrees Centigrade.
#
# The aim of this project is to show how to use the SPI bus library in
# MicroPython programs.
#
#
#
# Program : 	bargraph.py
# Date    : 	May, 2017
# Programmer: 	Dogan Ibrahim
#------------------------------------------------------------------------------
import time
import dht
from machine import Pin, SPI

rst = Pin(4, Pin.OUT)		# Reset
en = Pin(2, Pin.OUT)		# Enable
LT = Pin(5, Pin.OUT)		# Latch

#
# This function returns the temperature
#
def Temp():
    d = dht.DHT11(Pin(0))
    d.measure()
    t = d.temperature()
    return t

#
# This function resets the BarGraph Click board
#
def reset():
   rst.low()
   time.sleep_us(1)
   rst.high()

#
# This function clocks the shift register data to the output registers
#
def clock():
   LT.low()
   time.sleep_us(1)
   LT.high()

#
# Turn on the LEDs on the BarGraph Click board
#
def BarGraph(dat):
   temp = 2**dat - 1
   temp1 = (temp & 0x00FF)
   temp2 = (temp & 0xFF00) >> 8
   spi.write(bytes([temp2]))
   spi.write(bytes([temp1]))
   clock()

#
# Main program. Initialize the SPI bus, enable the BarGraph Click
# board, read and display the temperature, repeat every 15 seconds
#
spi = SPI(1, baudrate=50000, polarity=0, phase=0)
en.high()
while True:
   reset()
   clock()
   t = (Temp() / 3)
   t = round(t)
   BarGraph(t)
   time.sleep(15)
   








   
















   

   