#-----------------------------------------------------------------------------
#              		USING THE I2C BUS FUNCTIONS
#	       		===========================
#
# In this project a MCP23017 port expande chip is connected to ports GPIO0
# and GPIO2 of the NodeMCU development board. MCP23017 is I2C bus compatible
# and it provides 2x8 ports to a microcontroller. This is a 28 pin chip and it
# operates with +3.3V.
#
# The aim of this project is to show how the I2C functions of MicroPython can
# be used in projects.
#
# In this project an LED is conencted to port pin GPA0 of the MCP23017 chip
# for testing and the LED is flashed every second. The SDA and SCL pins of the
# MCP23017 chip are connected to NodeMCU pins GPIO0 and GPIO2 respectively.
#
#
# Program : 	expander.py
# Date    : 	May, 2017
# Programmer: 	Dogan Ibrahim
#------------------------------------------------------------------------------
import time
from machine import Pin, I2C

slave_addr = 0x20		# MCP23017 address
IODIRA = 0x00			# IODIRA address
GPIOA = 0x12			# GPIOA address

#
# This function initializes the I2C bus and configures the MCP23017 chip such
# that Port pin GPA0 is configured as an output pin. PortDir is the address of
# teh port direction register (IODIRA or IODIRB), and Data is teh directin data
# such that 0 sets teh corresponding port pin to output, and 1 sets the 
# corresponding port pin to input
#
def configure(PortDir, Data):
    global slave_addr
    buf = bytearray(2)
    buf = bytes([PortDir, Data])
    i2c.start()
    i2c.writeto(slave_addr, buf)
    i2c.stop() 
#
# This function sends the Data to the specified Port. The Port can be GPIOA
# or GPIOB and Data is a byte (0 to 25)
#

def send(Port, Data):
    global slave_addri
    buf = bytearray(2)
    buf = bytes([Port, Data])
    i2c.start()
    i2c.writeto(slave_addr, buf)
    i2c.stop()

#
# Main program. Initialize the I2C, configure the GPIOA port and flash the
# LED connecte dto port pin GPA0 every second
#
i2c = I2C(scl = Pin(2), sda = Pin(0), freq = 100000)
configure(IODIRA, 0xFE)
while True:
    send(GPIOA, 0)			# LED OFF
    time.sleep(1)			# Wait 1 second
    send(GPIOA, 1)			# LED ON
    time.sleep(1)			# Wait 1 second


